@@ -20,30 +20,13 @@ from blockdiag.elements import *
 from blockdiag.utils.XY import XY
 
 
-class Diagram(blockdiag.elements.Diagram):
-    def __init__(self):
-        super(Diagram, self).__init__()
-
-        self.orientation = 'portrait'
-        self.node_width = 104
-        self.span_width = 48
-        self.span_height = 104
-        self.groups = []
-        self.networks = []
-
-    def fixiate(self):
-        if len(self.nodes) + len(self.networks) > 0:
-            nodes = self.nodes + self.networks
-            self.width = max(x.xy.x + x.width for x in nodes)
-            self.height = max(x.xy.y + x.height for x in nodes)
-
-
 class DiagramNode(blockdiag.elements.DiagramNode):
     def __init__(self, id):
         super(DiagramNode, self).__init__(id)
 
         self.address = {}
         self.networks = []
+        self.layouted = False
 
     def set_attributes(self, network, attrs):
         for attr in attrs:
@@ -99,8 +82,21 @@ class Network(blockdiag.elements.NodeGroup):
         return label
 
 
-class NodeGroup(blockdiag.elements.NodeGroup):
-    def __init__(self, id):
-        super(NodeGroup, self).__init__(id)
+class Diagram(blockdiag.elements.Diagram):
+    _DiagramNode = DiagramNode
 
-        self.layouted = False
+    def __init__(self):
+        super(Diagram, self).__init__()
+
+        self.orientation = 'portrait'
+        self.node_width = 104
+        self.span_width = 48
+        self.span_height = 104
+        self.groups = []
+        self.networks = []
+
+    def fixiate(self):
+        if len(self.nodes) + len(self.networks) > 0:
+            nodes = self.nodes + self.networks
+            self.width = max(x.xy.x + x.width for x in nodes)
+            self.height = max(x.xy.y + x.height for x in nodes)
